import pulumi
import pulumi.runtime

from ... import tables

class OwnerReference(pulumi.CustomResource):
    """
    OwnerReference contains enough information to let you identify an owning object. An owning
    object must be in the same namespace as the dependent, or be cluster-scoped, so there is no
    namespace field.
    """
    def __init__(self, __name__, __opts__=None, block_owner_deletion=None, controller=None, name=None, uid=None):
        if not __name__:
            raise TypeError('Missing resource name argument (for URN creation)')
        if not isinstance(__name__, str):
            raise TypeError('Expected resource name to be a string')
        if __opts__ and not isinstance(__opts__, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')

        __props__ = dict()

        __props__['apiVersion'] = 'meta/v1'
        __props__['kind'] = 'OwnerReference'
        if not name:
            raise TypeError('Missing required property name')
        __props__['name'] = name
        if not uid:
            raise TypeError('Missing required property uid')
        __props__['uid'] = uid
        __props__['blockOwnerDeletion'] = block_owner_deletion
        __props__['controller'] = controller

        super(OwnerReference, self).__init__(
            "kubernetes:meta/v1:OwnerReference",
            __name__,
            __props__,
            __opts__)

    def translate_output_property(self, prop: str) -> str:
        return tables._CASING_FORWARD_TABLE.get(prop) or prop

    def translate_input_property(self, prop: str) -> str:
        return tables._CASING_BACKWARD_TABLE.get(prop) or prop



import pulumi
import pulumi.runtime

from ... import tables

class APIVersions(pulumi.CustomResource):
    """
    APIVersions lists the versions that are available, to allow clients to discover the API at /api,
    which is the root path of the legacy v1 API.
    """
    def __init__(self, __name__, __opts__=None, server_address_by_client_cid_rs=None, versions=None):
        if not __name__:
            raise TypeError('Missing resource name argument (for URN creation)')
        if not isinstance(__name__, str):
            raise TypeError('Expected resource name to be a string')
        if __opts__ and not isinstance(__opts__, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')

        __props__ = dict()

        __props__['apiVersion'] = 'v1'
        __props__['kind'] = 'APIVersions'
        if not serverAddressByClientCIDRs:
            raise TypeError('Missing required property serverAddressByClientCIDRs')
        __props__['serverAddressByClientCIDRs'] = server_address_by_client_cid_rs
        if not versions:
            raise TypeError('Missing required property versions')
        __props__['versions'] = versions

        super(APIVersions, self).__init__(
            "kubernetes:core/v1:APIVersions",
            __name__,
            __props__,
            __opts__)

    def translate_output_property(self, prop: str) -> str:
        return tables._CASING_FORWARD_TABLE.get(prop) or prop

    def translate_input_property(self, prop: str) -> str:
        return tables._CASING_BACKWARD_TABLE.get(prop) or prop



import pulumi
import pulumi.runtime

from ... import tables

class Event(pulumi.CustomResource):
    """
    Event is a report of an event somewhere in the cluster. It generally denotes some state change
    in the system.
    """
    def __init__(self, __name__, __opts__=None, action=None, deprecated_count=None, deprecated_first_timestamp=None, deprecated_last_timestamp=None, deprecated_source=None, event_time=None, metadata=None, note=None, reason=None, regarding=None, related=None, reporting_controller=None, reporting_instance=None, series=None, type=None):
        if not __name__:
            raise TypeError('Missing resource name argument (for URN creation)')
        if not isinstance(__name__, str):
            raise TypeError('Expected resource name to be a string')
        if __opts__ and not isinstance(__opts__, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')

        __props__ = dict()

        __props__['apiVersion'] = 'events.k8s.io/v1beta1'
        __props__['kind'] = 'Event'
        if not eventTime:
            raise TypeError('Missing required property eventTime')
        __props__['eventTime'] = event_time
        __props__['action'] = action
        __props__['deprecatedCount'] = deprecated_count
        __props__['deprecatedFirstTimestamp'] = deprecated_first_timestamp
        __props__['deprecatedLastTimestamp'] = deprecated_last_timestamp
        __props__['deprecatedSource'] = deprecated_source
        __props__['metadata'] = metadata
        __props__['note'] = note
        __props__['reason'] = reason
        __props__['regarding'] = regarding
        __props__['related'] = related
        __props__['reportingController'] = reporting_controller
        __props__['reportingInstance'] = reporting_instance
        __props__['series'] = series
        __props__['type'] = type

        super(Event, self).__init__(
            "kubernetes:events.k8s.io/v1beta1:Event",
            __name__,
            __props__,
            __opts__)

    def translate_output_property(self, prop: str) -> str:
        return tables._CASING_FORWARD_TABLE.get(prop) or prop

    def translate_input_property(self, prop: str) -> str:
        return tables._CASING_BACKWARD_TABLE.get(prop) or prop



import pulumi
import pulumi.runtime

from ... import tables

class Subject(pulumi.CustomResource):
    """
    Subject contains a reference to the object or user identities a role binding applies to.  This
    can either hold a direct API object reference, or a value for non-objects such as user and group
    names.
    """
    def __init__(self, __name__, __opts__=None, name=None, namespace=None):
        if not __name__:
            raise TypeError('Missing resource name argument (for URN creation)')
        if not isinstance(__name__, str):
            raise TypeError('Expected resource name to be a string')
        if __opts__ and not isinstance(__opts__, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')

        __props__ = dict()

        __props__['apiVersion'] = 'rbac/v1alpha1'
        __props__['kind'] = 'Subject'
        if not name:
            raise TypeError('Missing required property name')
        __props__['name'] = name
        __props__['namespace'] = namespace

        super(Subject, self).__init__(
            "kubernetes:rbac/v1alpha1:Subject",
            __name__,
            __props__,
            __opts__)

    def translate_output_property(self, prop: str) -> str:
        return tables._CASING_FORWARD_TABLE.get(prop) or prop

    def translate_input_property(self, prop: str) -> str:
        return tables._CASING_BACKWARD_TABLE.get(prop) or prop



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Kubernetes codegen tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

# Export this package's modules as members:
from .APIGroup import *
from .APIGroupList import *
from .APIResourceList import *
from .APIVersions import *
from .DeleteOptions import *
from .OwnerReference import *
from .Status import *
